postgres

package
v0.0.0-...-f16e8f5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2024 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsConnectionClassError

func IsConnectionClassError(err error) bool

IsConnectionClassError returns true if the given error is Postgres based and if it is connection related

func NewDatabaseHandle

func NewDatabaseHandle(tx pgx.Tx) db.DatabaseHandle

NewDatabaseHandle creates a db.DatabaseHandle from the given transaction

func NewPostgresDb

func NewPostgresDb(cfg *db.DbConfig) (db.DB, app.Error)

NewPostgresDb connects to a postgres database described in the given db.DbConfig

Types

This section is empty.

Jump to